==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/EtwProviderConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.EtwProviderConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property events
 * @property id
 */
public data class EtwProviderConfigurationArgs(
    public val events: Output<List<EtwEventConfigurationArgs>>,
    public val id: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.EtwProviderConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.EtwProviderConfigurationArgs =
        com.pulumi.azurenative.insights.inputs.EtwProviderConfigurationArgs.builder()
            .events(events.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .id(id.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EtwProviderConfigurationArgs].
 */
@PulumiTagMarker
public class EtwProviderConfigurationArgsBuilder internal constructor() {
    private var events: Output<List<EtwEventConfigurationArgs>>? = null

    private var id: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("tlwuwbqukevlwycp")
    public suspend fun events(`value`: Output<List<EtwEventConfigurationArgs>>) {
        this.events = value
    }

    @JvmName("dupvhpaqtyfgkyfc")
    public suspend fun events(vararg values: Output<EtwEventConfigurationArgs>) {
        this.events = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("kwwvbpjcyqefusqm")
    public suspend fun events(values: List<Output<EtwEventConfigurationArgs>>) {
        this.events = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("qyigtimfilorydmh")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value
     */
    @JvmName("tsofvhfpkjrsnotl")
    public suspend fun events(`value`: List<EtwEventConfigurationArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.events = mapped
    }

    /**
     * @param argument
     */
    @JvmName("osbxxelmdoiwoqps")
    public suspend fun events(argument: List<suspend EtwEventConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EtwEventConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.events = mapped
    }

    /**
     * @param argument
     */
    @JvmName("lqhlwfiedamkdalh")
    public suspend fun events(vararg argument: suspend EtwEventConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            EtwEventConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.events = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ynfbkqysmsaexbiv")
    public suspend fun events(argument: suspend EtwEventConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EtwEventConfigurationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.events = mapped
    }

    /**
     * @param values
     */
    @JvmName("ejruxogkybobrrhw")
    public suspend fun events(vararg values: EtwEventConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.events = mapped
    }

    /**
     * @param value
     */
    @JvmName("epfautdmelupmbgy")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): EtwProviderConfigurationArgs = EtwProviderConfigurationArgs(
        events = events ?: throw PulumiNullFieldException("events"),
        id = id ?: throw PulumiNullFieldException("id"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/EtwProviderConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.EtwProviderConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property events
 * @property id
 */
public data class EtwProviderConfigurationArgs(
    public val events: Output<List<EtwEventConfigurationArgs>>,
    public val id: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.EtwProviderConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.EtwProviderConfigurationArgs =
        com.pulumi.azurenative.insights.inputs.EtwProviderConfigurationArgs.builder()
            .events(events.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .id(id.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EtwProviderConfigurationArgs].
 */
@PulumiTagMarker
public class EtwProviderConfigurationArgsBuilder internal constructor() {
    private var events: Output<List<EtwEventConfigurationArgs>>? = null

    private var id: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("xrdhxputqpyadyib")
    public suspend fun events(`value`: Output<List<EtwEventConfigurationArgs>>) {
        this.events = value
    }

    @JvmName("rnhihrnwqyejxhqm")
    public suspend fun events(vararg values: Output<EtwEventConfigurationArgs>) {
        this.events = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("mbgvrsiafqojlvpb")
    public suspend fun events(values: List<Output<EtwEventConfigurationArgs>>) {
        this.events = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("rfkckshoshijqkwr")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value
     */
    @JvmName("exhahnxbyobfnibn")
    public suspend fun events(`value`: List<EtwEventConfigurationArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.events = mapped
    }

    /**
     * @param argument
     */
    @JvmName("fyoevxhmjbiwxqlh")
    public suspend fun events(argument: List<suspend EtwEventConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EtwEventConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.events = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ngdshdnfxnwlwxuw")
    public suspend fun events(vararg argument: suspend EtwEventConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            EtwEventConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.events = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ihrlahbryakpvsow")
    public suspend fun events(argument: suspend EtwEventConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EtwEventConfigurationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.events = mapped
    }

    /**
     * @param values
     */
    @JvmName("dkjwplgbwlrevwty")
    public suspend fun events(vararg values: EtwEventConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.events = mapped
    }

    /**
     * @param value
     */
    @JvmName("fepmyihjcxpoihwq")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): EtwProviderConfigurationArgs = EtwProviderConfigurationArgs(
        events = events ?: throw PulumiNullFieldException("events"),
        id = id ?: throw PulumiNullFieldException("id"),
    )
}
